@@ -1,15 +1,16 @@
 package Nodejs::Util;
 
-our $DATE = '2018-01-03'; # DATE
-our $VERSION = '0.007'; # VERSION
+our $DATE = '2018-01-06'; # DATE
+our $VERSION = '0.008'; # VERSION
 
 use 5.010001;
-use strict;
+use strict 'subs', 'vars';
 use warnings;
 
 use Exporter qw(import);
 our @EXPORT_OK = qw(
                        get_nodejs_path
+                       nodejs_path
                        nodejs_available
                        system_nodejs
                        nodejs_module_path
@@ -29,7 +30,7 @@ _
     },
 );
 
-$SPEC{get_nodejs_path} = {
+$SPEC{nodejs_path} = {
     v => 1.1,
     summary => 'Check the availability of Node.js executable in PATH',
     description => <<'_',
@@ -43,7 +44,7 @@ _
     },
     result_naked => 1,
 };
-sub get_nodejs_path {
+sub nodejs_path {
     require File::Which;
     require IPC::System::Options;
 
@@ -68,6 +69,8 @@ sub get_nodejs_path {
     \@paths;
 }
 
+*get_nodejs_path = \&nodejs_path;
+
 $SPEC{nodejs_available} = {
     v => 1.1,
     summary => 'Check the availability of Node.js',
@@ -281,39 +284,13 @@ Nodejs::Util - Utilities related to Node.js
 
 =head1 VERSION
 
-This document describes version 0.007 of Nodejs::Util (from Perl distribution Nodejs-Util), released on 2018-01-03.
+This document describes version 0.008 of Nodejs::Util (from Perl distribution Nodejs-Util), released on 2018-01-06.
+
+=for Pod::Coverage ^(get_nodejs_path)$
 
 =head1 FUNCTIONS
 
 
-=head2 get_nodejs_path
-
-Usage:
-
- get_nodejs_path(%args) -> any
-
-Check the availability of Node.js executable in PATH.
-
-Return the path to executable or undef if none is available. Node.js is usually
-installed as 'node' or 'nodejs'.
-
-This function is not exported by default, but exportable.
-
-Arguments ('*' denotes required arguments):
-
-=over 4
-
-=item * B<all> => I<bool>
-
-Find all node.js instead of the first found.
-
-If this option is set to true, will return an array of paths intead of path.
-
-=back
-
-Return value:  (any)
-
-
 =head2 nodejs_available
 
 Usage:
@@ -365,6 +342,34 @@ that contains extra information.
 
 Return value:  (any)
 
+
+=head2 nodejs_path
+
+Usage:
+
+ nodejs_path(%args) -> any
+
+Check the availability of Node.js executable in PATH.
+
+Return the path to executable or undef if none is available. Node.js is usually
+installed as 'node' or 'nodejs'.
+
+This function is not exported by default, but exportable.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<all> => I<bool>
+
+Find all node.js instead of the first found.
+
+If this option is set to true, will return an array of paths intead of path.
+
+=back
+
+Return value:  (any)
+
 =head2 system_nodejs
 
 Usage:
